==> openshift-model-operatorhub-6.2.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CleanupStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CleanupStatusFluentImpl<A extends CleanupStatusFluent<A>> extends BaseFluent<A> implements CleanupStatusFluent<A>{
  public CleanupStatusFluentImpl() {
  }
  public CleanupStatusFluentImpl(CleanupStatus instance) {
    this.withPendingDeletion(instance.getPendingDeletion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<ResourceListBuilder> pendingDeletion = new ArrayList<ResourceListBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToPendingDeletion(Integer index,ResourceList item) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").add(index >= 0 ? index : _visitables.get("pendingDeletion").size(), builder);this.pendingDeletion.add(index >= 0 ? index : pendingDeletion.size(), builder); return (A)this;
  }
  public A setToPendingDeletion(Integer index,ResourceList item) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    ResourceListBuilder builder = new ResourceListBuilder(item);
    if (index < 0 || index >= _visitables.get("pendingDeletion").size()) { _visitables.get("pendingDeletion").add(builder); } else { _visitables.get("pendingDeletion").set(index, builder);}
    if (index < 0 || index >= pendingDeletion.size()) { pendingDeletion.add(builder); } else { pendingDeletion.set(index, builder);}
     return (A)this;
  }
  public A addToPendingDeletion(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList... items) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").add(builder);this.pendingDeletion.add(builder);} return (A)this;
  }
  public A addAllToPendingDeletion(Collection<ResourceList> items) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").add(builder);this.pendingDeletion.add(builder);} return (A)this;
  }
  public A removeFromPendingDeletion(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList... items) {
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").remove(builder);if (this.pendingDeletion != null) {this.pendingDeletion.remove(builder);}} return (A)this;
  }
  public A removeAllFromPendingDeletion(Collection<ResourceList> items) {
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").remove(builder);if (this.pendingDeletion != null) {this.pendingDeletion.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    if (pendingDeletion == null) return (A) this;
    final Iterator<ResourceListBuilder> each = pendingDeletion.iterator();
    final List visitables = _visitables.get("pendingDeletion");
    while (each.hasNext()) {
      ResourceListBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPendingDeletion instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceList> getPendingDeletion() {
    return pendingDeletion != null ? build(pendingDeletion) : null;
  }
  public List<ResourceList> buildPendingDeletion() {
    return pendingDeletion != null ? build(pendingDeletion) : null;
  }
  public ResourceList buildPendingDeletion(Integer index) {
    return this.pendingDeletion.get(index).build();
  }
  public ResourceList buildFirstPendingDeletion() {
    return this.pendingDeletion.get(0).build();
  }
  public ResourceList buildLastPendingDeletion() {
    return this.pendingDeletion.get(pendingDeletion.size() - 1).build();
  }
  public ResourceList buildMatchingPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    for (ResourceListBuilder item: pendingDeletion) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    for (ResourceListBuilder item: pendingDeletion) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPendingDeletion(List<ResourceList> pendingDeletion) {
    if (this.pendingDeletion != null) { _visitables.get("pendingDeletion").removeAll(this.pendingDeletion);}
    if (pendingDeletion != null) {this.pendingDeletion = new ArrayList(); for (ResourceList item : pendingDeletion){this.addToPendingDeletion(item);}} else { this.pendingDeletion = null;} return (A) this;
  }
  public A withPendingDeletion(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList... pendingDeletion) {
    if (this.pendingDeletion != null) {this.pendingDeletion.clear();}
    if (pendingDeletion != null) {for (ResourceList item :pendingDeletion){ this.addToPendingDeletion(item);}} return (A) this;
  }
  public Boolean hasPendingDeletion() {
    return pendingDeletion != null && !pendingDeletion.isEmpty();
  }
  public CleanupStatusFluent.PendingDeletionNested<A> addNewPendingDeletion() {
    return new CleanupStatusFluentImpl.PendingDeletionNestedImpl();
  }
  public CleanupStatusFluent.PendingDeletionNested<A> addNewPendingDeletionLike(ResourceList item) {
    return new CleanupStatusFluentImpl.PendingDeletionNestedImpl(-1, item);
  }
  public CleanupStatusFluent.PendingDeletionNested<A> setNewPendingDeletionLike(Integer index,ResourceList item) {
    return new CleanupStatusFluentImpl.PendingDeletionNestedImpl(index, item);
  }
  public CleanupStatusFluent.PendingDeletionNested<A> editPendingDeletion(Integer index) {
    if (pendingDeletion.size() <= index) throw new RuntimeException("Can't edit pendingDeletion. Index exceeds size.");
    return setNewPendingDeletionLike(index, buildPendingDeletion(index));
  }
  public CleanupStatusFluent.PendingDeletionNested<A> editFirstPendingDeletion() {
    if (pendingDeletion.size() == 0) throw new RuntimeException("Can't edit first pendingDeletion. The list is empty.");
    return setNewPendingDeletionLike(0, buildPendingDeletion(0));
  }
  public CleanupStatusFluent.PendingDeletionNested<A> editLastPendingDeletion() {
    int index = pendingDeletion.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last pendingDeletion. The list is empty.");
    return setNewPendingDeletionLike(index, buildPendingDeletion(index));
  }
  public CleanupStatusFluent.PendingDeletionNested<A> editMatchingPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    int index = -1;
    for (int i=0;i<pendingDeletion.size();i++) { 
    if (predicate.test(pendingDeletion.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching pendingDeletion. No match found.");
    return setNewPendingDeletionLike(index, buildPendingDeletion(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CleanupStatusFluentImpl that = (CleanupStatusFluentImpl) o;
    if (pendingDeletion != null ? !pendingDeletion.equals(that.pendingDeletion) :that.pendingDeletion != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(pendingDeletion,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (pendingDeletion != null && !pendingDeletion.isEmpty()) { sb.append("pendingDeletion:"); sb.append(pendingDeletion + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PendingDeletionNestedImpl<N> extends ResourceListFluentImpl<CleanupStatusFluent.PendingDeletionNested<N>> implements CleanupStatusFluent.PendingDeletionNested<N>,Nested<N>{
    PendingDeletionNestedImpl(Integer index,ResourceList item) {
      this.index = index;
      this.builder = new ResourceListBuilder(this, item);
    }
    PendingDeletionNestedImpl() {
      this.index = -1;
      this.builder = new ResourceListBuilder(this);
    }
    ResourceListBuilder builder;
    Integer index;
    public N and() {
      return (N) CleanupStatusFluentImpl.this.setToPendingDeletion(index,builder.build());
    }
    public N endPendingDeletion() {
      return and();
    }
    
  }
  
}

==> openshift-model-operatorhub-6.7.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/CleanupStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CleanupStatusFluentImpl<A extends CleanupStatusFluent<A>> extends BaseFluent<A> implements CleanupStatusFluent<A>{
  public CleanupStatusFluentImpl() {
  }
  public CleanupStatusFluentImpl(CleanupStatus instance) {
    if (instance != null) {
      this.withPendingDeletion(instance.getPendingDeletion());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<ResourceListBuilder> pendingDeletion = new ArrayList<ResourceListBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToPendingDeletion(int index,ResourceList item) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    ResourceListBuilder builder = new ResourceListBuilder(item);
    if (index < 0 || index >= pendingDeletion.size()) { _visitables.get("pendingDeletion").add(builder); pendingDeletion.add(builder); } else { _visitables.get("pendingDeletion").add(index, builder); pendingDeletion.add(index, builder);}
    return (A)this;
  }
  public A setToPendingDeletion(int index,ResourceList item) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    ResourceListBuilder builder = new ResourceListBuilder(item);
    if (index < 0 || index >= pendingDeletion.size()) { _visitables.get("pendingDeletion").add(builder); pendingDeletion.add(builder); } else { _visitables.get("pendingDeletion").set(index, builder); pendingDeletion.set(index, builder);}
    return (A)this;
  }
  public A addToPendingDeletion(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList... items) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").add(builder);this.pendingDeletion.add(builder);} return (A)this;
  }
  public A addAllToPendingDeletion(Collection<ResourceList> items) {
    if (this.pendingDeletion == null) {this.pendingDeletion = new ArrayList<ResourceListBuilder>();}
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").add(builder);this.pendingDeletion.add(builder);} return (A)this;
  }
  public A removeFromPendingDeletion(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList... items) {
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").remove(builder);if (this.pendingDeletion != null) {this.pendingDeletion.remove(builder);}} return (A)this;
  }
  public A removeAllFromPendingDeletion(Collection<ResourceList> items) {
    for (ResourceList item : items) {ResourceListBuilder builder = new ResourceListBuilder(item);_visitables.get("pendingDeletion").remove(builder);if (this.pendingDeletion != null) {this.pendingDeletion.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    if (pendingDeletion == null) return (A) this;
    final Iterator<ResourceListBuilder> each = pendingDeletion.iterator();
    final List visitables = _visitables.get("pendingDeletion");
    while (each.hasNext()) {
      ResourceListBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPendingDeletion instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceList> getPendingDeletion() {
    return pendingDeletion != null ? build(pendingDeletion) : null;
  }
  public List<ResourceList> buildPendingDeletion() {
    return pendingDeletion != null ? build(pendingDeletion) : null;
  }
  public ResourceList buildPendingDeletion(int index) {
    return this.pendingDeletion.get(index).build();
  }
  public ResourceList buildFirstPendingDeletion() {
    return this.pendingDeletion.get(0).build();
  }
  public ResourceList buildLastPendingDeletion() {
    return this.pendingDeletion.get(pendingDeletion.size() - 1).build();
  }
  public ResourceList buildMatchingPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    for (ResourceListBuilder item: pendingDeletion) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    for (ResourceListBuilder item: pendingDeletion) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPendingDeletion(List<ResourceList> pendingDeletion) {
    if (this.pendingDeletion != null) { _visitables.get("pendingDeletion").clear();}
    if (pendingDeletion != null) {this.pendingDeletion = new ArrayList(); for (ResourceList item : pendingDeletion){this.addToPendingDeletion(item);}} else { this.pendingDeletion = null;} return (A) this;
  }
  public A withPendingDeletion(io.fabric8.openshift.api.model.operatorhub.v1alpha1.ResourceList... pendingDeletion) {
    if (this.pendingDeletion != null) {this.pendingDeletion.clear(); _visitables.remove("pendingDeletion"); }
    if (pendingDeletion != null) {for (ResourceList item :pendingDeletion){ this.addToPendingDeletion(item);}} return (A) this;
  }
  public Boolean hasPendingDeletion() {
    return pendingDeletion != null && !pendingDeletion.isEmpty();
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> addNewPendingDeletion() {
    return new CleanupStatusFluentImpl.PendingDeletionNestedImpl();
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> addNewPendingDeletionLike(ResourceList item) {
    return new CleanupStatusFluentImpl.PendingDeletionNestedImpl(-1, item);
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> setNewPendingDeletionLike(int index,ResourceList item) {
    return new CleanupStatusFluentImpl.PendingDeletionNestedImpl(index, item);
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> editPendingDeletion(int index) {
    if (pendingDeletion.size() <= index) throw new RuntimeException("Can't edit pendingDeletion. Index exceeds size.");
    return setNewPendingDeletionLike(index, buildPendingDeletion(index));
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> editFirstPendingDeletion() {
    if (pendingDeletion.size() == 0) throw new RuntimeException("Can't edit first pendingDeletion. The list is empty.");
    return setNewPendingDeletionLike(0, buildPendingDeletion(0));
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> editLastPendingDeletion() {
    int index = pendingDeletion.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last pendingDeletion. The list is empty.");
    return setNewPendingDeletionLike(index, buildPendingDeletion(index));
  }
  public CleanupStatusFluentImpl.PendingDeletionNested<A> editMatchingPendingDeletion(Predicate<ResourceListBuilder> predicate) {
    int index = -1;
    for (int i=0;i<pendingDeletion.size();i++) { 
    if (predicate.test(pendingDeletion.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching pendingDeletion. No match found.");
    return setNewPendingDeletionLike(index, buildPendingDeletion(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CleanupStatusFluentImpl that = (CleanupStatusFluentImpl) o;
    if (!java.util.Objects.equals(pendingDeletion, that.pendingDeletion)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(pendingDeletion,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (pendingDeletion != null) { sb.append("pendingDeletion:"); sb.append(pendingDeletion + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class PendingDeletionNestedImpl<N> extends ResourceListFluentImpl<CleanupStatusFluentImpl.PendingDeletionNested<N>> implements CleanupStatusFluentImpl.PendingDeletionNested<N>,Nested<N>{
    PendingDeletionNestedImpl(int index,ResourceList item) {
      this.index = index;
      this.builder = new ResourceListBuilder(this, item);
    }
    PendingDeletionNestedImpl() {
      this.index = -1;
      this.builder = new ResourceListBuilder(this);
    }
    ResourceListBuilder builder;
    int index;
    public N and() {
      return (N) CleanupStatusFluentImpl.this.setToPendingDeletion(index,builder.build());
    }
    public N endPendingDeletion() {
      return and();
    }
    
  }
  
}
